Documentation
¶
Overview ¶
+kubebuilder:object:generate=true +fybrik:validation:schema
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CreateAssetRequest ¶ added in v0.7.0
type CreateAssetRequest struct {
// The destination catalog id in which the new asset will be created based on the information provided
// in ResourceMetadata and ResourceDetails field
DestinationCatalogID string `json:"destinationCatalogID"`
// +kubebuilder:validation:Optional
// Asset ID to be used for the created asset
DestinationAssetID string `json:"destinationAssetID,omitempty"`
// Source asset metadata like asset name, owner, geography, etc
ResourceMetadata ResourceMetadata `json:"resourceMetadata"`
// Source asset details like connection
// and data format
Details ResourceDetails `json:"details"`
// +kubebuilder:validation:Optional
// The vault plugin path where the destination data credentials will be stored as kubernetes secrets
Credentials string `json:"credentials"`
}
func (*CreateAssetRequest) DeepCopy ¶ added in v0.7.0
func (in *CreateAssetRequest) DeepCopy() *CreateAssetRequest
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CreateAssetRequest.
func (*CreateAssetRequest) DeepCopyInto ¶ added in v0.7.0
func (in *CreateAssetRequest) DeepCopyInto(out *CreateAssetRequest)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CreateAssetResponse ¶ added in v0.7.0
type CreateAssetResponse struct {
// The ID of the created asset based on the source asset information given in CreateAssetRequest object
AssetID string `json:"assetID"`
}
func (*CreateAssetResponse) DeepCopy ¶ added in v0.7.0
func (in *CreateAssetResponse) DeepCopy() *CreateAssetResponse
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CreateAssetResponse.
func (*CreateAssetResponse) DeepCopyInto ¶ added in v0.7.0
func (in *CreateAssetResponse) DeepCopyInto(out *CreateAssetResponse)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type DeleteAssetRequest ¶ added in v0.7.0
type DeleteAssetRequest struct {
// Asset ID of the to-be deleted asset
AssetID taxonomy.AssetID `json:"assetID"`
}
func (*DeleteAssetRequest) DeepCopy ¶ added in v0.7.0
func (in *DeleteAssetRequest) DeepCopy() *DeleteAssetRequest
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DeleteAssetRequest.
func (*DeleteAssetRequest) DeepCopyInto ¶ added in v0.7.0
func (in *DeleteAssetRequest) DeepCopyInto(out *DeleteAssetRequest)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type DeleteAssetResponse ¶ added in v0.7.0
type DeleteAssetResponse struct {
// +kubebuilder:validation:Optional
// The deletion status
Status string `json:"status,omitempty"`
}
func (*DeleteAssetResponse) DeepCopy ¶ added in v0.7.0
func (in *DeleteAssetResponse) DeepCopy() *DeleteAssetResponse
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DeleteAssetResponse.
func (*DeleteAssetResponse) DeepCopyInto ¶ added in v0.7.0
func (in *DeleteAssetResponse) DeepCopyInto(out *DeleteAssetResponse)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type GetAssetRequest ¶
type GetAssetRequest struct {
// Asset ID of the asset to be queried in the catalog
AssetID taxonomy.AssetID `json:"assetID"`
// +kubebuilder:validation:Enum=read;
OperationType OperationType `json:"operationType"`
}
func (*GetAssetRequest) DeepCopy ¶
func (in *GetAssetRequest) DeepCopy() *GetAssetRequest
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GetAssetRequest.
func (*GetAssetRequest) DeepCopyInto ¶
func (in *GetAssetRequest) DeepCopyInto(out *GetAssetRequest)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type GetAssetResponse ¶
type GetAssetResponse struct {
// Source asset metadata like asset name, owner, geography, etc
ResourceMetadata ResourceMetadata `json:"resourceMetadata"`
// Source asset details like connection and data format
Details ResourceDetails `json:"details"`
// Vault plugin path where the data credentials will be stored as kubernetes secrets
// This value is assumed to be known to the catalog connector.
Credentials string `json:"credentials"`
// Additional message to be reported to the user
Message string `json:"message,omitempty"`
}
func (*GetAssetResponse) DeepCopy ¶
func (in *GetAssetResponse) DeepCopy() *GetAssetResponse
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GetAssetResponse.
func (*GetAssetResponse) DeepCopyInto ¶
func (in *GetAssetResponse) DeepCopyInto(out *GetAssetResponse)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type OperationType ¶
type OperationType string
Type of operation requested for the asset
const (
READ OperationType = "read"
)
List of operationTypes
type ResourceColumn ¶
type ResourceColumn struct {
// Name of the column
Name string `json:"name"`
// Tags associated with the column
Tags *taxonomy.Tags `json:"tags,omitempty"`
}
ResourceColumn represents a column in a tabular resource
func (*ResourceColumn) DeepCopy ¶
func (in *ResourceColumn) DeepCopy() *ResourceColumn
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ResourceColumn.
func (*ResourceColumn) DeepCopyInto ¶
func (in *ResourceColumn) DeepCopyInto(out *ResourceColumn)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ResourceDetails ¶
type ResourceDetails struct {
// Connection information
Connection taxonomy.Connection `json:"connection"`
// Data format
DataFormat taxonomy.DataFormat `json:"dataFormat,omitempty"`
}
ResourceDetails includes asset connection details
func (*ResourceDetails) DeepCopy ¶
func (in *ResourceDetails) DeepCopy() *ResourceDetails
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ResourceDetails.
func (*ResourceDetails) DeepCopyInto ¶
func (in *ResourceDetails) DeepCopyInto(out *ResourceDetails)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ResourceMetadata ¶
type ResourceMetadata struct {
// Name of the resource
Name string `json:"name,omitempty"`
// Owner of the resource
Owner string `json:"owner,omitempty"`
// Geography of the resource
Geography string `json:"geography,omitempty"`
// Tags associated with the asset
Tags *taxonomy.Tags `json:"tags,omitempty"`
// Columns associated with the asset
Columns []ResourceColumn `json:"columns,omitempty"`
}
ResourceMetadata defines model for resource metadata
func (*ResourceMetadata) DeepCopy ¶
func (in *ResourceMetadata) DeepCopy() *ResourceMetadata
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ResourceMetadata.
func (*ResourceMetadata) DeepCopyInto ¶
func (in *ResourceMetadata) DeepCopyInto(out *ResourceMetadata)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type UpdateAssetRequest ¶ added in v0.7.0
type UpdateAssetRequest struct {
// The id of the dataset to be updated based on the information provided
// in ResourceMetadata and ResourceDetails field
AssetID taxonomy.AssetID `json:"assetID"`
// New name of the resource
Name string `json:"name,omitempty"`
// New owner of the resource
Owner string `json:"owner,omitempty"`
// New tags associated with the asset
Tags *taxonomy.Tags `json:"tags,omitempty"`
// New columns associated with the asset
Columns []ResourceColumn `json:"columns,omitempty"`
}
func (*UpdateAssetRequest) DeepCopy ¶ added in v0.7.0
func (in *UpdateAssetRequest) DeepCopy() *UpdateAssetRequest
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new UpdateAssetRequest.
func (*UpdateAssetRequest) DeepCopyInto ¶ added in v0.7.0
func (in *UpdateAssetRequest) DeepCopyInto(out *UpdateAssetRequest)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type UpdateAssetResponse ¶ added in v0.7.0
type UpdateAssetResponse struct {
// +kubebuilder:validation:Optional
// The updation status
Status string `json:"status,omitempty"`
}
func (*UpdateAssetResponse) DeepCopy ¶ added in v0.7.0
func (in *UpdateAssetResponse) DeepCopy() *UpdateAssetResponse
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new UpdateAssetResponse.
func (*UpdateAssetResponse) DeepCopyInto ¶ added in v0.7.0
func (in *UpdateAssetResponse) DeepCopyInto(out *UpdateAssetResponse)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.