Documentation
¶
Overview ¶
+kubebuilder:object:generate=true +fybrik:validation:schema
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type GetPolicyDecisionsRequest ¶
type GetPolicyDecisionsRequest struct {
Context taxonomy.PolicyManagerRequestContext `json:"context,omitempty"`
Action RequestAction `json:"action"`
Resource Resource `json:"resource"`
}
func (*GetPolicyDecisionsRequest) DeepCopy ¶
func (in *GetPolicyDecisionsRequest) DeepCopy() *GetPolicyDecisionsRequest
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GetPolicyDecisionsRequest.
func (*GetPolicyDecisionsRequest) DeepCopyInto ¶
func (in *GetPolicyDecisionsRequest) DeepCopyInto(out *GetPolicyDecisionsRequest)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type GetPolicyDecisionsResponse ¶
type GetPolicyDecisionsResponse struct {
DecisionID string `json:"decision_id,omitempty"`
// Additional message to be reported to the user
Message string `json:"message,omitempty"`
// Result of policy evaluation
Result []ResultItem `json:"result"`
}
func (*GetPolicyDecisionsResponse) DeepCopy ¶
func (in *GetPolicyDecisionsResponse) DeepCopy() *GetPolicyDecisionsResponse
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GetPolicyDecisionsResponse.
func (*GetPolicyDecisionsResponse) DeepCopyInto ¶
func (in *GetPolicyDecisionsResponse) DeepCopyInto(out *GetPolicyDecisionsResponse)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RequestAction ¶
type RequestAction struct {
ActionType taxonomy.DataFlow `json:"actionType"`
ProcessingLocation taxonomy.ProcessingLocation `json:"processingLocation,omitempty"`
Destination string `json:"destination,omitempty"`
}
RequestAction describes the reason for accessing the data, e.g., read/write/delete, where the data is processed or written to
func (*RequestAction) DeepCopy ¶
func (in *RequestAction) DeepCopy() *RequestAction
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RequestAction.
func (*RequestAction) DeepCopyInto ¶
func (in *RequestAction) DeepCopyInto(out *RequestAction)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Resource ¶
type Resource struct {
ID taxonomy.AssetID `json:"id"`
Metadata *datacatalog.ResourceMetadata `json:"metadata,omitempty"`
}
Asset metadata
func (*Resource) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Resource.
func (*Resource) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ResultItem ¶
type ResultItem struct {
// The policy on which the decision was based
Policy string `json:"policy"`
Action taxonomy.Action `json:"action"`
}
Result of policy evaluation
func (*ResultItem) DeepCopy ¶
func (in *ResultItem) DeepCopy() *ResultItem
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ResultItem.
func (*ResultItem) DeepCopyInto ¶
func (in *ResultItem) DeepCopyInto(out *ResultItem)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.